@@ -12,15 +12,21 @@ function tab($label, $action, $default=false) {
     $label = str_replace(' ', '&nbsp;', $label);
 
 	$ea = get('eaction',get('ea',''));	
-	if ($ea=='' || $ea=='saveedit' || $ea=='saveview')
+	if ($ea=='' || $ea=='save' || $ea=='saveview')
 		$active = $default;
 	else
 		$active = $ea==$action;
-		
+
+	if ($action == 'view') {
+		$query="";
+	}
+	else {
+		$query="?a=edit&ea=$action";
+	}
 	$class = $active ? "class=here" : "";
 	$accesskey = $key ? "accesskey=$key" : '';
 	echo "<td $class class=tab$count>";
-		echo alink("?a=edit&ea=$action", $label, $accesskey);
+		echo alink($query, $label, $accesskey);
 	echo "</td>\n";
 }
 
@@ -47,8 +53,7 @@ else {
 	tab('<u>E</u>dit Content','edit',true);
 	tab('<u>P</u>roperties','props');
 #	tab('Per<u>m</u>issions','perms');
-#	tab('Ve<u>r</u>sions','versions');
-	tab('P<u>r</u>eview','preview');
+	tab('<u>H</u>istory','history');
 	tab('Vie<u>w</u> Site','view');
 }
 
