@@ -7,20 +7,14 @@
 
 <div id=container>
 
-<table cellpadding=0 cellspacing=0 border=0><tr>
-<td valign=top>
-<div id=navcontainer><div id=nav>
+<div id=nav>
     <?php include("leftnav.php"); ?>
-</div></div>
-</td>
-
-<td valign=top>
+</div>
 <div id=content>
     <?= $content ?>
 </div>
+<br clear="both" />
 <p><?=@$page->get('footer')?>&nbsp;</p>
-</td>
-</tr></table>
 
 <?php if (!$robot) { ?>
 <div id=controls style="display: none">
